==> qmltube_0.4.4.tar.gz: qmltube-0.4.4/qml/qmltube/scripts/videolistscripts.js <==
/* Video list functions */

function appendVideoFeed() {
    videoListModel.loading = true;

    var startIndex = videoList.count + 1;
    var doc = new XMLHttpRequest();
    doc.onreadystatechange = function() {
        if (doc.readyState == XMLHttpRequest.DONE) {
            var xml = doc.responseText;
            videoListModel.appendXml(xml);
        }

        videoListModel.loading = false;
    }
    doc.open("GET", videoFeed + "&start-index=" + startIndex);
    if (YouTube.currentUser != "") {
        doc.setRequestHeader("Authorization", "GoogleLogin auth=" + YouTube.accessToken);
    }
    doc.send();
}

function showVideoDialog(index) {
    if (dialog.source == "") {
        dimmer.state = "dim";
        dialog.source = "VideoListDialog.qml";
        var video = videoListModel.get(index);
        dialog.item.setVideo(video);
        dialog.item.infoClicked.connect(goToVideo);
        dialog.item.playClicked.connect(playVideo);
        dialog.item.close.connect(closeDialogs);
        videoList.interactive = false;
        mouseArea.enabled = true;
    }
}

function showPlaylistDialog() {
    if (dialog.source == "") {
        dimmer.state = "dim";
        dialog.source = "AddToPlaylistDialog.qml";
        dialog.item.playlistClicked.connect(addVideosToPlaylist);
        videoList.interactive = false;
        mouseArea.enabled = true;
    }
}

function playVideo(playerUrl) {
    YouTube.getVideoUrl(playerUrl);
}

function addVideosToPlaybackQueue() {
    var list = [];
    for (var i = 0; i < videoList.checkList.length; i++) {
        var video = videoListModel.get(videoList.checkList[i]);
        list.push(video);
    }
    videoList.checkList = [];
    playVideos(list);
}

function addVideosToDownloads(convertToAudio) {
    for (var i = 0; i < videoList.checkList.length; i++) {
        var video = videoListModel.get(videoList.checkList[i]);
        if (convertToAudio) {
            addAudioDownload(video);
        }
        else {
            addDownload(video);
        }
    }
    videoList.checkList = [];
}

function addVideosToPlaylist(playlistId) {
    closeDialogs();
    for (var i = 0; i < videoList.checkList.length; i++) {
        var videoId = videoListModel.get(videoList.checkList[i]).videoId;
        toggleBusy(true);
        YouTube.addToPlaylist(videoId, playlistId);
    }
    videoList.checkList = [];
}

function addVideosToFavourites() {
    for (var i = 0; i < videoList.checkList.length; i++) {
        var videoId = videoListModel.get(videoList.checkList[i]).videoId;
        toggleBusy(true);
        YouTube.addToFavourites(videoId);
    }
    videoList.checkList = [];
}

function copyVideosToClipboard() {
    var urls = "";
    for (var i = 0; i < videoList.checkList.length; i++) {
        var url = videoListModel.get(videoList.checkList[i]).playerUrl.split("&")[0];
        urls = urls + url + "\n";
    }
    Controller.copyToClipboard(urls);
    videoList.checkList = [];
}

function rotateDialogs() {
    if (dialog.source != "") {
        dialog.item.state = window.state;
    }
}

function closeDialogs() {
    /* Close any open dialogs and return the window to its default state */

    dialog.state = "";
    timer.running = true;
    dimmer.state = "";
    mouseArea.enabled = false;
    videoList.interactive = true;
}

function showUserInfoDialog() {
    if (dialog.source == "") {
        dimmer.state = "dim";
        dialog.source = "UserInfoDialog.qml";
        dialog.item.subscribeClicked.connect(setSubscription);
        dialog.item.getUserProfile(username, isSubscribed);
        videoList.interactive = false;
        mouseArea.enabled = true;
    }
}

function setSubscription() {
    if (userIsSignedIn()) {
        toggleBusy(true);
        if (isSubscribed) {
            YouTube.unsubscribeToChannel(subscriptionId);
        }
        else {
            YouTube.subscribeToChannel(username);
        }
    }
    else {
        displayMessage("You are not signed in to a YouTube account");
    }
    closeDialogs();
}

function indexInCheckList(index) {
    var result = false;
    for (var i = 0; i < videoList.checkList.length; i ++) {
        if (videoList.checkList[i] == index) {
            result = true;
        }
    }
    return result;
}

function showOrHideFilter() {
    if (listFilter.source == "") {
        if ((event.key != Qt.Key_Left)
                && (event.key != Qt.Key_Right)
                && (event.key != Qt.Key_Up)
                && (event.key != Qt.Key_Down)
                && (event.key != Qt.Key_Control)
                && (event.key != Qt.Key_Shift)
                && (event.key != Qt.Key_Enter)
                && (event.key != Qt.Key_Return)
                && (event.key != Qt.Key_Backspace)) {
            listFilter.source = "ListFilter.qml";
            listFilter.item.filterString = event.text;
        }
    }
}

==> qmltube_0.5.1.tar.gz: qmltube-0.5.1/qml/qmltube/scripts/videolistscripts.js <==
/* Video list functions */

function appendVideoFeed() {
    videoListModel.loading = true;

    var startIndex = videoList.count + 1;
    var doc = new XMLHttpRequest();
    doc.onreadystatechange = function() {
        if (doc.readyState == XMLHttpRequest.DONE) {
            var xml = doc.responseText;
            videoListModel.appendXml(xml);
        }

        videoListModel.loading = false;
    }
    doc.open("GET", videoFeed + "&start-index=" + startIndex);
    if (YouTube.currentUser != "") {
        doc.setRequestHeader("Authorization", "GoogleLogin auth=" + YouTube.accessToken);
    }
    doc.send();
}

function showVideoDialog(index) {
    if (dimmer.state == "") {
        toggleControls(false);
        var video = videoListModel.get(index);
        var videoDialog = ObjectCreator.createObject("VideoListDialog.qml", window);
        videoDialog.setVideo(video);
        videoDialog.infoClicked.connect(goToVideo);
        videoDialog.playClicked.connect(playVideo);
        videoDialog.close.connect(closeDialogs);
        dimmer.state = "dim";
        videoDialog.state = "show";
        mouseArea.enabled = true;
    }
}

function showPlaylistDialog() {
    if (dimmer.state == "") {
        toggleControls(false);
        var playlistDialog = ObjectCreator.createObject("AddToPlaylistDialog.qml", window);
        playlistDialog.playlistClicked.connect(addVideosToPlaylist);
        playlistDialog.close.connect(closeDialogs);
        dimmer.state = "dim";
        playlistDialog.state = "show";
        mouseArea.enabled = true;
    }
}

function playVideo(playerUrl) {
    YouTube.getVideoUrl(playerUrl);
}

function addVideosToPlaybackQueue() {
    var list = [];
    for (var i = 0; i < videoList.checkList.length; i++) {
        var video = videoListModel.get(videoList.checkList[i]);
        list.push(video);
    }
    videoList.checkList = [];
    playVideos(list);
}

function addVideosToDownloads(convertToAudio) {
    for (var i = 0; i < videoList.checkList.length; i++) {
        var video = videoListModel.get(videoList.checkList[i]);
        if (convertToAudio) {
            addAudioDownload(video);
        }
        else {
            addDownload(video);
        }
    }
    videoList.checkList = [];
}

function addVideosToPlaylist(playlistId) {
    closeDialogs();
    for (var i = 0; i < videoList.checkList.length; i++) {
        var videoId = videoListModel.get(videoList.checkList[i]).videoId;
        toggleBusy(true);
        YouTube.addToPlaylist(videoId, playlistId);
    }
    videoList.checkList = [];
}

function addVideosToFavourites() {
    for (var i = 0; i < videoList.checkList.length; i++) {
        var videoId = videoListModel.get(videoList.checkList[i]).videoId;
        toggleBusy(true);
        YouTube.addToFavourites(videoId);
    }
    videoList.checkList = [];
}

function copyVideosToClipboard() {
    var urls = "";
    for (var i = 0; i < videoList.checkList.length; i++) {
        var url = videoListModel.get(videoList.checkList[i]).playerUrl.split("&")[0];
        urls = urls + url + "\n";
    }
    Controller.copyToClipboard(urls);
    videoList.checkList = [];
}

function closeDialogs() {
    /* Close any open dialogs and return the window to its default state */

    dialogClose();
    dimmer.state = "";
    mouseArea.enabled = false;
    toggleControls(true);
}

function setSubscription() {
    if (userIsSignedIn()) {
        toggleBusy(true);
        if (isSubscribed) {
            YouTube.unsubscribeToChannel(subscriptionId);
        }
        else {
            YouTube.subscribeToChannel(username);
        }
    }
    else {
        displayMessage("You are not signed in to a YouTube account");
    }
    closeDialogs();
}

function indexInCheckList(index) {
    var result = false;
    for (var i = 0; i < videoList.checkList.length; i ++) {
        if (videoList.checkList[i] == index) {
            result = true;
        }
    }
    return result;
}

function showOrHideFilter() {
    if (listFilter.source == "") {
        if ((event.key != Qt.Key_Left)
                && (event.key != Qt.Key_Right)
                && (event.key != Qt.Key_Up)
                && (event.key != Qt.Key_Down)
                && (event.key != Qt.Key_Control)
                && (event.key != Qt.Key_Shift)
                && (event.key != Qt.Key_Enter)
                && (event.key != Qt.Key_Return)
                && (event.key != Qt.Key_Backspace)) {
            listFilter.source = "ListFilter.qml";
            listFilter.item.filterString = event.text;
        }
    }
}
